# Function reference {.doc .doc-index}

## Rational functions

How rational functions are represented in `pyratapprox`.

| | |
| --- | --- |
| [JuliaRatfun](JuliaRatfun.qmd#pyratapprox.JuliaRatfun) | Python wrapper for Julia rational functions. |
| [JuliaRatinterp](JuliaRatinterp.qmd#pyratapprox.JuliaRatinterp) | Python wrapper for Julia rational interpolants. |
| [Bary](Bary.qmd#pyratapprox.Bary) | Barycentric rational interpolant. |
| [Thiele](Thiele.qmd#pyratapprox.Thiele) | Thiele continued fraction interpolant. |

## Approximations

Rational approximations over domains.

| | |
| --- | --- |
| [JuliaApprox](JuliaApprox.qmd#pyratapprox.JuliaApprox) | Base class for rational function approximations. |
| [ContinuumApprox](ContinuumApprox.qmd#pyratapprox.ContinuumApprox) | Rational approximation on a continuum domain. |
| [DiscreteApprox](DiscreteApprox.qmd#pyratapprox.DiscreteApprox) | Rational approximation on a discrete point set. |